@@ -7,9 +7,17 @@ Init function for the thermal printer library.
 * Author(s): Tony DiCola
 """
 
-from adafruit_thermal_printer.thermal_printer import JUSTIFY_LEFT, \
-JUSTIFY_CENTER, JUSTIFY_RIGHT, SIZE_SMALL, SIZE_MEDIUM, SIZE_LARGE, \
-UNDERLINE_THIN, UNDERLINE_THICK
+from adafruit_thermal_printer.thermal_printer import (
+    JUSTIFY_LEFT,
+    JUSTIFY_CENTER,
+    JUSTIFY_RIGHT,
+    SIZE_SMALL,
+    SIZE_MEDIUM,
+    SIZE_LARGE,
+    UNDERLINE_THIN,
+    UNDERLINE_THICK,
+)
+
 
 def get_printer_class(version):
     """Retrieve the class to construct for an instance of the specified
@@ -20,10 +28,12 @@ def get_printer_class(version):
     """
     assert version is not None
     assert version >= 0.0
+    # pylint: disable=import-outside-toplevel
     if version < 2.64:
         import adafruit_thermal_printer.thermal_printer_legacy as thermal_printer
     elif version < 2.68:
         import adafruit_thermal_printer.thermal_printer_264 as thermal_printer
     else:
         import adafruit_thermal_printer.thermal_printer as thermal_printer
+    # pylint: enable=import-outside-toplevel
     return thermal_printer.ThermalPrinter
